==> apache-doris-1.1.5-src.tar.gz: apache-doris-1.1.5-src/docs/en/community/feedback.md <==
---
{ "title": "Feedback", "language": "zh-CN" }
---

<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Feedback

## Feedback Tips

- Describe the problem in detail, providing important details (logs, critical errors, investigations/analyses that have been performed)
- Minimize the problem, analyze the problem by yourself - narrow the scope of the problem, easy to answer / troubleshoot
- Give the minimization specific reproduction steps
- focus on the problem itself, as unrelated to the business/scenario as possible (if necessary, provide as clear and unambiguous context as possible)

## Feedback Method

If you find any problems or suggestions while using Doris, you can provide feedback in the following ways:

1. Mailing List

   You can send an email with any subject and content to `dev-subscribe@doris.apache.org`, and then follow the instructions to subscribe to this mailing list.

   After that, you can send an email to `dev@doris.apache.org` to describe the problem or suggestion.

2. Github

   Submit a [Github Issue](https://github.com/apache/incubator-doris/issues/new/choose)

==> apache-doris-2.1.11-rc01-src.tar.gz: apache-doris-2.1.11-rc01-src/docs/en/community/feedback.md <==
---
{
    "title": "Feedback",
    "language": "en"
}
---

<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Feedback

## Feedback Tips

- Describe the problem in detail, providing important details (logs, critical errors, investigations/analyses that have been performed)
- Minimize the problem, analyze the problem by yourself - narrow the scope of the problem, easy to answer / troubleshoot
- Give the minimization specific reproduction steps
- focus on the problem itself, as unrelated to the business/scenario as possible (if necessary, provide as clear and unambiguous context as possible)

## Feedback Method

If you find any problems or suggestions while using Doris, you can provide feedback in the following ways:

1. Mailing List

   You can send an email with any subject and content to `dev-subscribe@doris.apache.org`, and then follow the instructions to subscribe to this mailing list.

   After that, you can send an email to `dev@doris.apache.org` to describe the problem or suggestion.

2. Github

   Submit a [Github Issue](https://github.com/apache/doris/issues/new/choose)
